@@ -3,7 +3,7 @@ package Parse::RecDescent::FAQ;
 use vars qw($VERSION);
 
 
-our $VERSION = sprintf '%s', q$Revision: 1.2 $ =~ /Revision:\s+(\S+)\s+/ ;
+our $VERSION = '5.02';
 
 1;
 __END__
@@ -191,6 +191,15 @@ Here is an example of removing C comments in program text
 
 	statement: # etc...
 
+However, thanks to Chas Owens, we have an update that works for
+him. Instead of just C<x> as a regular expression modifier he had to
+add s as well:
+
+
+ program: <skip: qr{\s* (/[*] .*? [*]/ \s*)*}xs> statement(s)
+
+
+
 =head3 Quoting within a skip expression:
 
 Here is my script:
@@ -622,6 +631,7 @@ So if you would like to state the test in the positive, then do this:
 
 =head1 MODULAR / GENERATIVE / CREATIVE / HAIRY PARSING
 
+
 Be sure to see the example see the RESOURCES section at the end
 for even more nosebleed parsing examples.
 
@@ -2367,6 +2377,9 @@ L<http://groups.google.com/groups?q=recdescent&start=40&hl=en&scoring=d&rnum=41&
 
 =head1 RESOURCES
 
+=head2 "Some Parse::RecDescent Tutorials"
+
+L<http://perlmonks.org/?node_id=108182>
 
 =head2 Craig's Parse::Recdescent Area
 
@@ -2379,7 +2392,7 @@ as well as some slides for a presentation:
 
     http://www.perlmonks.org/index.pl?node_id=180778
 
-17 tips you cannot do without.
+17 tips you cannot do without... recently updated!
 
 
 
@@ -2480,6 +2493,8 @@ The (unwitting) contributors to this FAQ
 
 =over 4 
 
+=item * Chas Owens
+
 =item * Brent Dax
 
 =item * Damian Conway
@@ -2498,6 +2513,7 @@ The (unwitting) contributors to this FAQ
 
 =item * Yves Orton
 
+
 =back 
 
 
